import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

class AppButton extends StatelessWidget {
  final Function onTap;
  final String text;
  final double width;
  final Color color;
  final Color disabledColor;
  final Color focusColor;
  final Color hoverColor;
  final Color splashColor;
  final EdgeInsetsGeometry padding;
  final TextStyle textStyle;
  final ShapeBorder shapeBorder;
  final Widget child;
  final double elevation;
  final double height;
  final bool enabled;

  AppButton({
    this.onTap,
    this.text,
    this.width,
    this.color,
    this.padding,
    this.textStyle,
    this.shapeBorder,
    this.child,
    this.elevation,
    this.enabled,
    this.height,
    this.disabledColor,
    this.focusColor,
    this.hoverColor,
    this.splashColor,
  });

  @override
  Widget build(BuildContext context) {
    return MaterialButton(
      minWidth: width,
      padding: padding ?? EdgeInsets.only(left: 8, right: 8),
      onPressed: enabled.validate(value: true) ? onTap : null,
      color: color ?? Theme.of(context).primaryColor,
      child: child ??
          Text(text.validate(),
              style: textStyle ?? boldTextStyle(color: Colors.white)),
      shape: shapeBorder ??
          RoundedRectangleBorder(borderRadius: radius(defaultAppButtonRadius)),
      elevation: elevation,
      animationDuration: Duration(milliseconds: 3),
      height: height,
      disabledColor: disabledColor,
      focusColor: focusColor,
      hoverColor: hoverColor,
      splashColor: splashColor,
    );
  }
}
