import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

enum SymbolType { Bullet, Numbered, Custom }

/// Add UL to its children
class UL extends StatelessWidget {
  final List<Widget> children;
  final double padding;
  final double spacing;
  final SymbolType symbolType;
  final Color symbolColor;
  final Color textColor;
  final Widget customSymbol;

  UL({
    this.children,
    this.padding = 8,
    this.spacing = 8,
    this.symbolType = SymbolType.Bullet,
    this.symbolColor,
    this.textColor,
    this.customSymbol,
  });

  @override
  Widget build(BuildContext context) {
    return Wrap(
      runSpacing: spacing,
      direction: Axis.horizontal,
      children: children
          .validate()
          .asMap()
          .map((i, element) => MapEntry(
                i,
                Row(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    symbolType == SymbolType.Bullet
                        ? Transform.scale(
                            scale: 2.0,
                            child: Text(
                              '•',
                              style: TextStyle(
                                  color: textColor ?? textPrimaryColorGlobal),
                            ),
                          )
                        : SizedBox(),
                    symbolType == SymbolType.Numbered
                        ? Text('${i + 1}',
                            style: TextStyle(
                                fontSize: 16,
                                color: symbolColor ?? textPrimaryColorGlobal))
                        : SizedBox(),
                    (symbolType == SymbolType.Custom && customSymbol != null)
                        ? customSymbol
                        : SizedBox(),
                    SizedBox(width: padding),
                    element.expand(),
                  ],
                ),
              ))
          .values
          .toList(),
    );
  }
}
